Learn R Programming

gRaven (version 1.1.10)

compile.gRaven: Compile a gRaven domain

Description

Compile a gRaven domain

Usage

# S3 method for gRaven
compile(object, ...)
check.compiled(object)

Value

a NULL value is invisibly returned.

Arguments

object

name of gRaven domain

...

additional arguments to compile

Author

Peter J. Green, P.J.Green@bristol.ac.uk

Details

check.compiled compiles the domain if necessary, having first ensured that necessary information such as cptables is in place. If the domain is already compiled, compile triggers a warning, but proceeds to re-initialise the grain object domain$net, in particular deleting any evidence set.

Examples

Run this code
chest<-hugin.domain()
add.node(chest,"asia",states=c("yes","no"))
add.node(chest,"tub",states=c("yes","no"))
add.edge(chest,"tub","asia")
chest
compile(chest)
chest
set.finding(chest,"asia","yes")
set.finding(chest,"dysp","no")
propagate(chest)
chest$nodes
chest$states
chest$parents

Run the code above in your browser using DataLab