Learn R Programming

gRaven (version 1.1.10)

get.parents: Get the parents of a node in a gRaven domain

Description

Get the parents of a node in a gRaven domain

Usage

get.parents(domain, n, type = "parents")

Value

A named list of character vectors of names of parents.

Arguments

domain

name of gRaven domain

n

name of node

type

only "parents" is currently accepted

Author

Peter J. Green, P.J.Green@bristol.ac.uk

Examples

Run this code
demo("chest",package="gRaven",echo=FALSE)
get.nodes(chest)
chest$states
sapply(get.nodes(chest),function(x) get.parents(chest,x))

Run the code above in your browser using DataLab