Learn R Programming

gRaven (version 1.1.10)

propagate.gRaven: Propagate method for a gRaven domain

Description

Propagate method for a gRaven domain

Usage

# S3 method for gRaven
propagate(object, ...)

Value

a NULL value is invisibly returned.

Arguments

object

character string, name of gRaven domain

...

additional arguments to propagate

Author

Peter J. Green, P.J.Green@bristol.ac.uk

Details

Propagates all previously entered evidence through the network. This call is required by functions such as get.belief and map.configurations, but not before get.normalization.constant. In the implementation, findings will have been accumulated in the variable net$cache in the domain, by calls to set.finding, and are moved to net$evid by the propagate function.

Examples

Run this code
demo("chest",package="gRaven",echo=FALSE)
compile(chest)
chest
set.finding(chest,"asia","yes")
set.finding(chest,"dysp","no")
propagate(chest)
get.belief(chest,"asia")
get.belief(chest,"tub")

Run the code above in your browser using DataLab