Learn R Programming

gRaven (version 1.1.10)

summary.gRaven: Summary method for a gRaven domain

Description

Summary method for a gRaven domain

Usage

# S3 method for gRaven
summary(object, domain = TRUE, nodes = FALSE, jt = FALSE, print.cliques = FALSE, 
    ...)

Value

a data frame.

Arguments

object

character string, name of gRaven domain

domain

Logical, should domain be summarised

jt

Logical, should junction tree be summarised

nodes

Logical, should nodes be summarised

print.cliques

Logical, should cliques be printed

...

additional arguments to summary

Differences from RHugin

In gRaven, not all of the options are yet implemented, and generally the information delivered is less detailed than in the RHugin version.

Author

Peter J. Green, P.J.Green@bristol.ac.uk

Examples

Run this code
demo("chest",package="gRaven",echo=FALSE)
chest
summary(chest,jt=TRUE)

Run the code above in your browser using DataLab