powered by
Get the parents of a node in a gRaven domain
get.parents(domain, n, type = "parents")
A named list of character vectors of names of parents.
name of gRaven domain
name of node
only "parents" is currently accepted
Peter J. Green, P.J.Green@bristol.ac.uk
demo("chest",package="gRaven",echo=FALSE) get.nodes(chest) chest$states sapply(get.nodes(chest),function(x) get.parents(chest,x))
Run the code above in your browser using DataLab