Propagates all previously entered evidence through the network. This call is required by functions such as get.belief and map.configurations, but not before get.normalization.constant. In the implementation, findings will have been accumulated in the variable net$cache in the domain, by calls to set.finding, and are moved to net$evid by the propagate function.