powered by
Summary method for a gRaven domain
# S3 method for gRaven summary(object, domain = TRUE, nodes = FALSE, jt = FALSE, print.cliques = FALSE, ...)
a data frame.
character string, name of gRaven domain
Logical, should domain be summarised
Logical, should junction tree be summarised
Logical, should nodes be summarised
Logical, should cliques be printed
additional arguments to summary
summary
In gRaven, not all of the options are yet implemented, and generally the information delivered is less detailed than in the RHugin version.
gRaven
RHugin
Peter J. Green, P.J.Green@bristol.ac.uk
demo("chest",package="gRaven",echo=FALSE) chest summary(chest,jt=TRUE)
Run the code above in your browser using DataLab